/*-
 * ACPI Source Language Compiler
 *
 * Copyright (c) 2000 Mitsuru IWASAKI <iwasaki@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD$
 */

#ifndef _ASLC_H_
#define _ASLC_H_

#include <sys/queue.h>

extern int			 parser_phase;
extern int			 parser_debuglevel;
extern int			 parser_not_initialized;
extern int			 parser_lineno;

extern void			 parser_main(const char *asl_filename);
extern void			 parser_warn(const char *msg, ...);
extern void			 parser_error(const char *msg, ...);
extern void			 parser_fatal(const char *msg, ...);

enum {
	LITERAL_INTEGER,
	LITERAL_STRING,
	LITERAL_MAX
};

union asl_literal {
	int		 type;
	struct {
		int		 type;
		u_int32_t	 val;
		int		 bytes;
	} num;
	struct {
		int		 type;
		char		*ptr;
	} str;
};

enum {
	SYM_METHOD,
	SYM_FIELD,
	SYM_MAX
};

struct asl_symtab {
	TAILQ_ENTRY(asl_symtab)	links;
	char			*name;
	int			 type;
	union {
		struct {
			u_int8_t	flags;
		} method;
	} data;
};

extern struct asl_symtab	*symtab_new(const char *name, int type);
extern struct asl_symtab	*symtab_find(const char *name);
extern void			 symtab_dump(void);
extern void			 symtab_destroy(void);
extern const char		*symtab_getname(struct asl_symtab *sym);
extern void			 symtab_method_setflags(struct asl_symtab *sym,
							int flags);
extern u_int8_t			 symtab_method_getnumargs(struct asl_symtab *sym);

extern void			 yyerror(const char *msg);
extern int			 yyparse(void);
extern int			 yylex(void);
extern int			 yydebug;

#endif	/* !_ASLC_H_ */
